@@ -4,11 +4,15 @@ from datetime import timedelta
 
 from logilab.common.testlib import TestCase, unittest_main
 
-from cubicweb.devtools.testlib import AutomaticWebTest
-
-from cubicweb.devtools.testlib import AutomaticWebTest
+from cubicweb.devtools.testlib import CubicWebTC, AutomaticWebTest
 from cubicweb.devtools.fill import ValueGenerator
 
+class SchemaTC(CubicWebTC):
+    def test(self):
+        req = self.request()
+        wo = req.create_entity('WorkOrder', title=u'hop')
+        wo.cw_unrelated_rql('todo_by', 'Resource', 'subject')
+
 class TimeSheetValueGenerator(ValueGenerator):
 
     def generate_Calendaruse_stop(self, entity, index):
