@@ -2,7 +2,7 @@
 """activity related views.
 
 :organization: Logilab
-:copyright: 2007-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2014 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -152,7 +152,7 @@ class ValidateActivitiesAction(action.Action):
         def validate_cb(req, eids):
             for eid in eids:
                 entity = req.entity_from_eid(eid, 'Activity')
-                entity.fire_transition('validate')
+                entity.cw_adapt_to('IWorkflowable').fire_transition('validate')
         msg = self._cw._('activities validated')
         return self._cw.user_callback(validate_cb, (eids,), msg)
 
